"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListRepositoryAssociations = void 0;
const CodeGuruReviewer_1 = require("../CodeGuruReviewer");
const CodeGuruReviewerClient_1 = require("../CodeGuruReviewerClient");
const ListRepositoryAssociationsCommand_1 = require("../commands/ListRepositoryAssociationsCommand");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListRepositoryAssociationsCommand_1.ListRepositoryAssociationsCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.listRepositoryAssociations(input, ...args);
};
async function* paginateListRepositoryAssociations(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.NextToken = token;
        input["MaxResults"] = config.pageSize;
        if (config.client instanceof CodeGuruReviewer_1.CodeGuruReviewer) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof CodeGuruReviewerClient_1.CodeGuruReviewerClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected CodeGuruReviewer | CodeGuruReviewerClient");
        }
        yield page;
        token = page.NextToken;
        hasNext = !!token;
    }
    return undefined;
}
exports.paginateListRepositoryAssociations = paginateListRepositoryAssociations;
