import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { CodeGuruReviewerClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../CodeGuruReviewerClient";
import { AssociateRepositoryRequest, AssociateRepositoryResponse } from "../models/models_0";
export interface AssociateRepositoryCommandInput extends AssociateRepositoryRequest {
}
export interface AssociateRepositoryCommandOutput extends AssociateRepositoryResponse, __MetadataBearer {
}
/**
 * <p>
 *          Use to associate an Amazon Web Services CodeCommit repository or a repostory managed by
 *          Amazon Web Services CodeStar Connections with Amazon CodeGuru Reviewer. When you associate a
 *         repository, CodeGuru Reviewer reviews source code changes in the repository's pull requests and provides
 *         automatic recommendations. You can view recommendations using the CodeGuru Reviewer console. For more information, see
 *          <a href="https://docs.aws.amazon.com/codeguru/latest/reviewer-ug/recommendations.html">Recommendations in
 *             Amazon CodeGuru Reviewer</a> in the <i>Amazon CodeGuru Reviewer User Guide.</i>
 *         </p>
 *
 *          <p>If you associate a CodeCommit or S3 repository, it must be in the same
 *          Amazon Web Services Region and Amazon Web Services account where its CodeGuru Reviewer code reviews are configured.</p>
 *
 *          <p>Bitbucket and GitHub Enterprise Server repositories are managed by Amazon Web Services CodeStar
 *          Connections to connect to CodeGuru Reviewer. For more information, see <a href="https://docs.aws.amazon.com/codeguru/latest/reviewer-ug/getting-started-associate-repository.html">Associate a repository</a> in
 *          the <i>Amazon CodeGuru Reviewer User Guide.</i>
 *          </p>
 *
 *          <note>
 *             <p>
 *             You cannot use the CodeGuru Reviewer SDK or the Amazon Web Services CLI to associate a GitHub repository with Amazon CodeGuru Reviewer. To associate
 *             a GitHub repository, use the console. For more information, see
 *             <a href="https://docs.aws.amazon.com/codeguru/latest/reviewer-ug/getting-started-with-guru.html">Getting
 *             started with CodeGuru Reviewer</a> in the <i>CodeGuru Reviewer User Guide.</i>
 *             </p>
 *          </note>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CodeGuruReviewerClient, AssociateRepositoryCommand } from "@aws-sdk/client-codeguru-reviewer"; // ES Modules import
 * // const { CodeGuruReviewerClient, AssociateRepositoryCommand } = require("@aws-sdk/client-codeguru-reviewer"); // CommonJS import
 * const client = new CodeGuruReviewerClient(config);
 * const command = new AssociateRepositoryCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link AssociateRepositoryCommandInput} for command's `input` shape.
 * @see {@link AssociateRepositoryCommandOutput} for command's `response` shape.
 * @see {@link CodeGuruReviewerClientResolvedConfig | config} for CodeGuruReviewerClient's `config` shape.
 *
 */
export declare class AssociateRepositoryCommand extends $Command<AssociateRepositoryCommandInput, AssociateRepositoryCommandOutput, CodeGuruReviewerClientResolvedConfig> {
    readonly input: AssociateRepositoryCommandInput;
    constructor(input: AssociateRepositoryCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: CodeGuruReviewerClientResolvedConfig, options?: __HttpHandlerOptions): Handler<AssociateRepositoryCommandInput, AssociateRepositoryCommandOutput>;
    private serialize;
    private deserialize;
}
