import { EndpointsInputConfig, EndpointsResolvedConfig, RegionInputConfig, RegionResolvedConfig } from "@aws-sdk/config-resolver";
import { HostHeaderInputConfig, HostHeaderResolvedConfig } from "@aws-sdk/middleware-host-header";
import { RetryInputConfig, RetryResolvedConfig } from "@aws-sdk/middleware-retry";
import { AwsAuthInputConfig, AwsAuthResolvedConfig } from "@aws-sdk/middleware-signing";
import { UserAgentInputConfig, UserAgentResolvedConfig } from "@aws-sdk/middleware-user-agent";
import { HttpHandler as __HttpHandler } from "@aws-sdk/protocol-http";
import { Client as __Client, DefaultsMode, SmithyConfiguration as __SmithyConfiguration, SmithyResolvedConfiguration as __SmithyResolvedConfiguration } from "@aws-sdk/smithy-client";
import { BodyLengthCalculator as __BodyLengthCalculator, Credentials as __Credentials, Decoder as __Decoder, Encoder as __Encoder, HashConstructor as __HashConstructor, HttpHandlerOptions as __HttpHandlerOptions, Logger as __Logger, Provider as __Provider, Provider, RegionInfoProvider, StreamCollector as __StreamCollector, UrlParser as __UrlParser, UserAgent as __UserAgent } from "@aws-sdk/types";
import { AssociateRepositoryCommandInput, AssociateRepositoryCommandOutput } from "./commands/AssociateRepositoryCommand";
import { CreateCodeReviewCommandInput, CreateCodeReviewCommandOutput } from "./commands/CreateCodeReviewCommand";
import { DescribeCodeReviewCommandInput, DescribeCodeReviewCommandOutput } from "./commands/DescribeCodeReviewCommand";
import { DescribeRecommendationFeedbackCommandInput, DescribeRecommendationFeedbackCommandOutput } from "./commands/DescribeRecommendationFeedbackCommand";
import { DescribeRepositoryAssociationCommandInput, DescribeRepositoryAssociationCommandOutput } from "./commands/DescribeRepositoryAssociationCommand";
import { DisassociateRepositoryCommandInput, DisassociateRepositoryCommandOutput } from "./commands/DisassociateRepositoryCommand";
import { ListCodeReviewsCommandInput, ListCodeReviewsCommandOutput } from "./commands/ListCodeReviewsCommand";
import { ListRecommendationFeedbackCommandInput, ListRecommendationFeedbackCommandOutput } from "./commands/ListRecommendationFeedbackCommand";
import { ListRecommendationsCommandInput, ListRecommendationsCommandOutput } from "./commands/ListRecommendationsCommand";
import { ListRepositoryAssociationsCommandInput, ListRepositoryAssociationsCommandOutput } from "./commands/ListRepositoryAssociationsCommand";
import { ListTagsForResourceCommandInput, ListTagsForResourceCommandOutput } from "./commands/ListTagsForResourceCommand";
import { PutRecommendationFeedbackCommandInput, PutRecommendationFeedbackCommandOutput } from "./commands/PutRecommendationFeedbackCommand";
import { TagResourceCommandInput, TagResourceCommandOutput } from "./commands/TagResourceCommand";
import { UntagResourceCommandInput, UntagResourceCommandOutput } from "./commands/UntagResourceCommand";
export declare type ServiceInputTypes = AssociateRepositoryCommandInput | CreateCodeReviewCommandInput | DescribeCodeReviewCommandInput | DescribeRecommendationFeedbackCommandInput | DescribeRepositoryAssociationCommandInput | DisassociateRepositoryCommandInput | ListCodeReviewsCommandInput | ListRecommendationFeedbackCommandInput | ListRecommendationsCommandInput | ListRepositoryAssociationsCommandInput | ListTagsForResourceCommandInput | PutRecommendationFeedbackCommandInput | TagResourceCommandInput | UntagResourceCommandInput;
export declare type ServiceOutputTypes = AssociateRepositoryCommandOutput | CreateCodeReviewCommandOutput | DescribeCodeReviewCommandOutput | DescribeRecommendationFeedbackCommandOutput | DescribeRepositoryAssociationCommandOutput | DisassociateRepositoryCommandOutput | ListCodeReviewsCommandOutput | ListRecommendationFeedbackCommandOutput | ListRecommendationsCommandOutput | ListRepositoryAssociationsCommandOutput | ListTagsForResourceCommandOutput | PutRecommendationFeedbackCommandOutput | TagResourceCommandOutput | UntagResourceCommandOutput;
export interface ClientDefaults extends Partial<__SmithyResolvedConfiguration<__HttpHandlerOptions>> {
    
    requestHandler?: __HttpHandler;
    
    sha256?: __HashConstructor;
    
    urlParser?: __UrlParser;
    
    bodyLengthChecker?: __BodyLengthCalculator;
    
    streamCollector?: __StreamCollector;
    
    base64Decoder?: __Decoder;
    
    base64Encoder?: __Encoder;
    
    utf8Decoder?: __Decoder;
    
    utf8Encoder?: __Encoder;
    
    runtime?: string;
    
    disableHostPrefix?: boolean;
    
    maxAttempts?: number | __Provider<number>;
    
    retryMode?: string | __Provider<string>;
    
    logger?: __Logger;
    
    useDualstackEndpoint?: boolean | __Provider<boolean>;
    
    useFipsEndpoint?: boolean | __Provider<boolean>;
    
    serviceId?: string;
    
    region?: string | __Provider<string>;
    
    credentialDefaultProvider?: (input: any) => __Provider<__Credentials>;
    
    regionInfoProvider?: RegionInfoProvider;
    
    defaultUserAgentProvider?: Provider<__UserAgent>;
    
    defaultsMode?: DefaultsMode | Provider<DefaultsMode>;
}
declare type CodeGuruReviewerClientConfigType = Partial<__SmithyConfiguration<__HttpHandlerOptions>> & ClientDefaults & RegionInputConfig & EndpointsInputConfig & RetryInputConfig & HostHeaderInputConfig & AwsAuthInputConfig & UserAgentInputConfig;

export interface CodeGuruReviewerClientConfig extends CodeGuruReviewerClientConfigType {
}
declare type CodeGuruReviewerClientResolvedConfigType = __SmithyResolvedConfiguration<__HttpHandlerOptions> & Required<ClientDefaults> & RegionResolvedConfig & EndpointsResolvedConfig & RetryResolvedConfig & HostHeaderResolvedConfig & AwsAuthResolvedConfig & UserAgentResolvedConfig;

export interface CodeGuruReviewerClientResolvedConfig extends CodeGuruReviewerClientResolvedConfigType {
}

export declare class CodeGuruReviewerClient extends __Client<__HttpHandlerOptions, ServiceInputTypes, ServiceOutputTypes, CodeGuruReviewerClientResolvedConfig> {
    
    readonly config: CodeGuruReviewerClientResolvedConfig;
    constructor(configuration: CodeGuruReviewerClientConfig);
    
    destroy(): void;
}
export {};
