import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { CodeGuruReviewerServiceException as __BaseException } from "./CodeGuruReviewerServiceException";

export declare class AccessDeniedException extends __BaseException {
    readonly name: "AccessDeniedException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<AccessDeniedException, __BaseException>);
}
export declare enum AnalysisType {
    CODE_QUALITY = "CodeQuality",
    SECURITY = "Security"
}
export declare enum EncryptionOption {
    AoCmk = "AWS_OWNED_CMK",
    CmCmk = "CUSTOMER_MANAGED_CMK"
}

export interface KMSKeyDetails {
    
    KMSKeyId?: string;
    
    EncryptionOption?: EncryptionOption | string;
}
export declare namespace KMSKeyDetails {
    
    const filterSensitiveLog: (obj: KMSKeyDetails) => any;
}

export interface ThirdPartySourceRepository {
    
    Name: string | undefined;
    
    ConnectionArn: string | undefined;
    
    Owner: string | undefined;
}
export declare namespace ThirdPartySourceRepository {
    
    const filterSensitiveLog: (obj: ThirdPartySourceRepository) => any;
}

export interface CodeCommitRepository {
    
    Name: string | undefined;
}
export declare namespace CodeCommitRepository {
    
    const filterSensitiveLog: (obj: CodeCommitRepository) => any;
}

export interface S3Repository {
    
    Name: string | undefined;
    
    BucketName: string | undefined;
}
export declare namespace S3Repository {
    
    const filterSensitiveLog: (obj: S3Repository) => any;
}

export interface Repository {
    
    CodeCommit?: CodeCommitRepository;
    
    Bitbucket?: ThirdPartySourceRepository;
    
    GitHubEnterpriseServer?: ThirdPartySourceRepository;
    
    S3Bucket?: S3Repository;
}
export declare namespace Repository {
    
    const filterSensitiveLog: (obj: Repository) => any;
}
export interface AssociateRepositoryRequest {
    
    Repository: Repository | undefined;
    
    ClientRequestToken?: string;
    
    Tags?: {
        [key: string]: string;
    };
    
    KMSKeyDetails?: KMSKeyDetails;
}
export declare namespace AssociateRepositoryRequest {
    
    const filterSensitiveLog: (obj: AssociateRepositoryRequest) => any;
}
export declare enum ProviderType {
    BITBUCKET = "Bitbucket",
    CODE_COMMIT = "CodeCommit",
    GIT_HUB = "GitHub",
    GIT_HUB_ENTERPRISE_SERVER = "GitHubEnterpriseServer",
    S3_BUCKET = "S3Bucket"
}

export interface CodeArtifacts {
    
    SourceCodeArtifactsObjectKey: string | undefined;
    
    BuildArtifactsObjectKey?: string;
}
export declare namespace CodeArtifacts {
    
    const filterSensitiveLog: (obj: CodeArtifacts) => any;
}

export interface S3RepositoryDetails {
    
    BucketName?: string;
    
    CodeArtifacts?: CodeArtifacts;
}
export declare namespace S3RepositoryDetails {
    
    const filterSensitiveLog: (obj: S3RepositoryDetails) => any;
}
export declare enum RepositoryAssociationState {
    ASSOCIATED = "Associated",
    ASSOCIATING = "Associating",
    DISASSOCIATED = "Disassociated",
    DISASSOCIATING = "Disassociating",
    FAILED = "Failed"
}

export interface RepositoryAssociation {
    
    AssociationId?: string;
    
    AssociationArn?: string;
    
    ConnectionArn?: string;
    
    Name?: string;
    
    Owner?: string;
    
    ProviderType?: ProviderType | string;
    
    State?: RepositoryAssociationState | string;
    
    StateReason?: string;
    
    LastUpdatedTimeStamp?: Date;
    
    CreatedTimeStamp?: Date;
    
    KMSKeyDetails?: KMSKeyDetails;
    
    S3RepositoryDetails?: S3RepositoryDetails;
}
export declare namespace RepositoryAssociation {
    
    const filterSensitiveLog: (obj: RepositoryAssociation) => any;
}
export interface AssociateRepositoryResponse {
    
    RepositoryAssociation?: RepositoryAssociation;
    
    Tags?: {
        [key: string]: string;
    };
}
export declare namespace AssociateRepositoryResponse {
    
    const filterSensitiveLog: (obj: AssociateRepositoryResponse) => any;
}

export declare class ConflictException extends __BaseException {
    readonly name: "ConflictException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}

export declare class InternalServerException extends __BaseException {
    readonly name: "InternalServerException";
    readonly $fault: "server";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<InternalServerException, __BaseException>);
}

export declare class ThrottlingException extends __BaseException {
    readonly name: "ThrottlingException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ThrottlingException, __BaseException>);
}

export declare class ValidationException extends __BaseException {
    readonly name: "ValidationException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ValidationException, __BaseException>);
}

export interface RepositoryHeadSourceCodeType {
    
    BranchName: string | undefined;
}
export declare namespace RepositoryHeadSourceCodeType {
    
    const filterSensitiveLog: (obj: RepositoryHeadSourceCodeType) => any;
}

export interface BranchDiffSourceCodeType {
    
    SourceBranchName: string | undefined;
    
    DestinationBranchName: string | undefined;
}
export declare namespace BranchDiffSourceCodeType {
    
    const filterSensitiveLog: (obj: BranchDiffSourceCodeType) => any;
}

export interface CommitDiffSourceCodeType {
    
    SourceCommit?: string;
    
    DestinationCommit?: string;
    
    MergeBaseCommit?: string;
}
export declare namespace CommitDiffSourceCodeType {
    
    const filterSensitiveLog: (obj: CommitDiffSourceCodeType) => any;
}

export interface EventInfo {
    
    Name?: string;
    
    State?: string;
}
export declare namespace EventInfo {
    
    const filterSensitiveLog: (obj: EventInfo) => any;
}
export declare enum VendorName {
    GITHUB = "GitHub",
    GITLAB = "GitLab",
    NATIVE_S3 = "NativeS3"
}

export interface RequestMetadata {
    
    RequestId?: string;
    
    Requester?: string;
    
    EventInfo?: EventInfo;
    
    VendorName?: VendorName | string;
}
export declare namespace RequestMetadata {
    
    const filterSensitiveLog: (obj: RequestMetadata) => any;
}

export interface S3BucketRepository {
    
    Name: string | undefined;
    
    Details?: S3RepositoryDetails;
}
export declare namespace S3BucketRepository {
    
    const filterSensitiveLog: (obj: S3BucketRepository) => any;
}

export interface SourceCodeType {
    
    CommitDiff?: CommitDiffSourceCodeType;
    
    RepositoryHead?: RepositoryHeadSourceCodeType;
    
    BranchDiff?: BranchDiffSourceCodeType;
    
    S3BucketRepository?: S3BucketRepository;
    
    RequestMetadata?: RequestMetadata;
}
export declare namespace SourceCodeType {
    
    const filterSensitiveLog: (obj: SourceCodeType) => any;
}

export interface RepositoryAnalysis {
    
    RepositoryHead?: RepositoryHeadSourceCodeType;
    
    SourceCodeType?: SourceCodeType;
}
export declare namespace RepositoryAnalysis {
    
    const filterSensitiveLog: (obj: RepositoryAnalysis) => any;
}

export interface CodeReviewType {
    
    RepositoryAnalysis: RepositoryAnalysis | undefined;
    
    AnalysisTypes?: (AnalysisType | string)[];
}
export declare namespace CodeReviewType {
    
    const filterSensitiveLog: (obj: CodeReviewType) => any;
}
export interface CreateCodeReviewRequest {
    
    Name: string | undefined;
    
    RepositoryAssociationArn: string | undefined;
    
    Type: CodeReviewType | undefined;
    
    ClientRequestToken?: string;
}
export declare namespace CreateCodeReviewRequest {
    
    const filterSensitiveLog: (obj: CreateCodeReviewRequest) => any;
}

export interface Metrics {
    
    MeteredLinesOfCodeCount?: number;
    
    FindingsCount?: number;
}
export declare namespace Metrics {
    
    const filterSensitiveLog: (obj: Metrics) => any;
}
export declare enum JobState {
    COMPLETED = "Completed",
    DELETING = "Deleting",
    FAILED = "Failed",
    PENDING = "Pending"
}
export declare enum Type {
    PULL_REQUEST = "PullRequest",
    REPOSITORY_ANALYSIS = "RepositoryAnalysis"
}

export interface CodeReview {
    
    Name?: string;
    
    CodeReviewArn?: string;
    
    RepositoryName?: string;
    
    Owner?: string;
    
    ProviderType?: ProviderType | string;
    
    State?: JobState | string;
    
    StateReason?: string;
    
    CreatedTimeStamp?: Date;
    
    LastUpdatedTimeStamp?: Date;
    
    Type?: Type | string;
    
    PullRequestId?: string;
    
    SourceCodeType?: SourceCodeType;
    
    AssociationArn?: string;
    
    Metrics?: Metrics;
    
    AnalysisTypes?: (AnalysisType | string)[];
}
export declare namespace CodeReview {
    
    const filterSensitiveLog: (obj: CodeReview) => any;
}
export interface CreateCodeReviewResponse {
    
    CodeReview?: CodeReview;
}
export declare namespace CreateCodeReviewResponse {
    
    const filterSensitiveLog: (obj: CreateCodeReviewResponse) => any;
}

export declare class ResourceNotFoundException extends __BaseException {
    readonly name: "ResourceNotFoundException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>);
}
export interface DescribeCodeReviewRequest {
    
    CodeReviewArn: string | undefined;
}
export declare namespace DescribeCodeReviewRequest {
    
    const filterSensitiveLog: (obj: DescribeCodeReviewRequest) => any;
}
export interface DescribeCodeReviewResponse {
    
    CodeReview?: CodeReview;
}
export declare namespace DescribeCodeReviewResponse {
    
    const filterSensitiveLog: (obj: DescribeCodeReviewResponse) => any;
}
export interface DescribeRecommendationFeedbackRequest {
    
    CodeReviewArn: string | undefined;
    
    RecommendationId: string | undefined;
    
    UserId?: string;
}
export declare namespace DescribeRecommendationFeedbackRequest {
    
    const filterSensitiveLog: (obj: DescribeRecommendationFeedbackRequest) => any;
}
export declare enum Reaction {
    THUMBS_DOWN = "ThumbsDown",
    THUMBS_UP = "ThumbsUp"
}

export interface RecommendationFeedback {
    
    CodeReviewArn?: string;
    
    RecommendationId?: string;
    
    Reactions?: (Reaction | string)[];
    
    UserId?: string;
    
    CreatedTimeStamp?: Date;
    
    LastUpdatedTimeStamp?: Date;
}
export declare namespace RecommendationFeedback {
    
    const filterSensitiveLog: (obj: RecommendationFeedback) => any;
}
export interface DescribeRecommendationFeedbackResponse {
    
    RecommendationFeedback?: RecommendationFeedback;
}
export declare namespace DescribeRecommendationFeedbackResponse {
    
    const filterSensitiveLog: (obj: DescribeRecommendationFeedbackResponse) => any;
}
export interface DescribeRepositoryAssociationRequest {
    
    AssociationArn: string | undefined;
}
export declare namespace DescribeRepositoryAssociationRequest {
    
    const filterSensitiveLog: (obj: DescribeRepositoryAssociationRequest) => any;
}
export interface DescribeRepositoryAssociationResponse {
    
    RepositoryAssociation?: RepositoryAssociation;
    
    Tags?: {
        [key: string]: string;
    };
}
export declare namespace DescribeRepositoryAssociationResponse {
    
    const filterSensitiveLog: (obj: DescribeRepositoryAssociationResponse) => any;
}

export declare class NotFoundException extends __BaseException {
    readonly name: "NotFoundException";
    readonly $fault: "client";
    Message?: string;
    
    constructor(opts: __ExceptionOptionType<NotFoundException, __BaseException>);
}
export interface DisassociateRepositoryRequest {
    
    AssociationArn: string | undefined;
}
export declare namespace DisassociateRepositoryRequest {
    
    const filterSensitiveLog: (obj: DisassociateRepositoryRequest) => any;
}
export interface DisassociateRepositoryResponse {
    
    RepositoryAssociation?: RepositoryAssociation;
    
    Tags?: {
        [key: string]: string;
    };
}
export declare namespace DisassociateRepositoryResponse {
    
    const filterSensitiveLog: (obj: DisassociateRepositoryResponse) => any;
}
export interface ListCodeReviewsRequest {
    
    ProviderTypes?: (ProviderType | string)[];
    
    States?: (JobState | string)[];
    
    RepositoryNames?: string[];
    
    Type: Type | string | undefined;
    
    MaxResults?: number;
    
    NextToken?: string;
}
export declare namespace ListCodeReviewsRequest {
    
    const filterSensitiveLog: (obj: ListCodeReviewsRequest) => any;
}

export interface MetricsSummary {
    
    MeteredLinesOfCodeCount?: number;
    
    FindingsCount?: number;
}
export declare namespace MetricsSummary {
    
    const filterSensitiveLog: (obj: MetricsSummary) => any;
}

export interface CodeReviewSummary {
    
    Name?: string;
    
    CodeReviewArn?: string;
    
    RepositoryName?: string;
    
    Owner?: string;
    
    ProviderType?: ProviderType | string;
    
    State?: JobState | string;
    
    CreatedTimeStamp?: Date;
    
    LastUpdatedTimeStamp?: Date;
    
    Type?: Type | string;
    
    PullRequestId?: string;
    
    MetricsSummary?: MetricsSummary;
    
    SourceCodeType?: SourceCodeType;
}
export declare namespace CodeReviewSummary {
    
    const filterSensitiveLog: (obj: CodeReviewSummary) => any;
}
export interface ListCodeReviewsResponse {
    
    CodeReviewSummaries?: CodeReviewSummary[];
    
    NextToken?: string;
}
export declare namespace ListCodeReviewsResponse {
    
    const filterSensitiveLog: (obj: ListCodeReviewsResponse) => any;
}
export interface ListRecommendationFeedbackRequest {
    
    NextToken?: string;
    
    MaxResults?: number;
    
    CodeReviewArn: string | undefined;
    
    UserIds?: string[];
    
    RecommendationIds?: string[];
}
export declare namespace ListRecommendationFeedbackRequest {
    
    const filterSensitiveLog: (obj: ListRecommendationFeedbackRequest) => any;
}

export interface RecommendationFeedbackSummary {
    
    RecommendationId?: string;
    
    Reactions?: (Reaction | string)[];
    
    UserId?: string;
}
export declare namespace RecommendationFeedbackSummary {
    
    const filterSensitiveLog: (obj: RecommendationFeedbackSummary) => any;
}
export interface ListRecommendationFeedbackResponse {
    
    RecommendationFeedbackSummaries?: RecommendationFeedbackSummary[];
    
    NextToken?: string;
}
export declare namespace ListRecommendationFeedbackResponse {
    
    const filterSensitiveLog: (obj: ListRecommendationFeedbackResponse) => any;
}
export interface ListRecommendationsRequest {
    
    NextToken?: string;
    
    MaxResults?: number;
    
    CodeReviewArn: string | undefined;
}
export declare namespace ListRecommendationsRequest {
    
    const filterSensitiveLog: (obj: ListRecommendationsRequest) => any;
}
export declare enum RecommendationCategory {
    AWS_BEST_PRACTICES = "AWSBestPractices",
    AWS_CLOUDFORMATION_ISSUES = "AWSCloudFormationIssues",
    CODE_INCONSISTENCIES = "CodeInconsistencies",
    CODE_MAINTENANCE_ISSUES = "CodeMaintenanceIssues",
    CONCURRENCY_ISSUES = "ConcurrencyIssues",
    DUPLICATE_CODE = "DuplicateCode",
    INPUT_VALIDATIONS = "InputValidations",
    JAVA_BEST_PRACTICES = "JavaBestPractices",
    PYTHON_BEST_PRACTICES = "PythonBestPractices",
    RESOURCE_LEAKS = "ResourceLeaks",
    SECURITY_ISSUES = "SecurityIssues"
}

export interface RuleMetadata {
    
    RuleId?: string;
    
    RuleName?: string;
    
    ShortDescription?: string;
    
    LongDescription?: string;
    
    RuleTags?: string[];
}
export declare namespace RuleMetadata {
    
    const filterSensitiveLog: (obj: RuleMetadata) => any;
}
export declare enum Severity {
    CRITICAL = "Critical",
    HIGH = "High",
    INFO = "Info",
    LOW = "Low",
    MEDIUM = "Medium"
}

export interface RecommendationSummary {
    
    FilePath?: string;
    
    RecommendationId?: string;
    
    StartLine?: number;
    
    EndLine?: number;
    
    Description?: string;
    
    RecommendationCategory?: RecommendationCategory | string;
    
    RuleMetadata?: RuleMetadata;
    
    Severity?: Severity | string;
}
export declare namespace RecommendationSummary {
    
    const filterSensitiveLog: (obj: RecommendationSummary) => any;
}
export interface ListRecommendationsResponse {
    
    RecommendationSummaries?: RecommendationSummary[];
    
    NextToken?: string;
}
export declare namespace ListRecommendationsResponse {
    
    const filterSensitiveLog: (obj: ListRecommendationsResponse) => any;
}
export interface ListRepositoryAssociationsRequest {
    
    ProviderTypes?: (ProviderType | string)[];
    
    States?: (RepositoryAssociationState | string)[];
    
    Names?: string[];
    
    Owners?: string[];
    
    MaxResults?: number;
    
    NextToken?: string;
}
export declare namespace ListRepositoryAssociationsRequest {
    
    const filterSensitiveLog: (obj: ListRepositoryAssociationsRequest) => any;
}

export interface RepositoryAssociationSummary {
    
    AssociationArn?: string;
    
    ConnectionArn?: string;
    
    LastUpdatedTimeStamp?: Date;
    
    AssociationId?: string;
    
    Name?: string;
    
    Owner?: string;
    
    ProviderType?: ProviderType | string;
    
    State?: RepositoryAssociationState | string;
}
export declare namespace RepositoryAssociationSummary {
    
    const filterSensitiveLog: (obj: RepositoryAssociationSummary) => any;
}
export interface ListRepositoryAssociationsResponse {
    
    RepositoryAssociationSummaries?: RepositoryAssociationSummary[];
    
    NextToken?: string;
}
export declare namespace ListRepositoryAssociationsResponse {
    
    const filterSensitiveLog: (obj: ListRepositoryAssociationsResponse) => any;
}
export interface ListTagsForResourceRequest {
    
    resourceArn: string | undefined;
}
export declare namespace ListTagsForResourceRequest {
    
    const filterSensitiveLog: (obj: ListTagsForResourceRequest) => any;
}
export interface ListTagsForResourceResponse {
    
    Tags?: {
        [key: string]: string;
    };
}
export declare namespace ListTagsForResourceResponse {
    
    const filterSensitiveLog: (obj: ListTagsForResourceResponse) => any;
}
export interface PutRecommendationFeedbackRequest {
    
    CodeReviewArn: string | undefined;
    
    RecommendationId: string | undefined;
    
    Reactions: (Reaction | string)[] | undefined;
}
export declare namespace PutRecommendationFeedbackRequest {
    
    const filterSensitiveLog: (obj: PutRecommendationFeedbackRequest) => any;
}
export interface PutRecommendationFeedbackResponse {
}
export declare namespace PutRecommendationFeedbackResponse {
    
    const filterSensitiveLog: (obj: PutRecommendationFeedbackResponse) => any;
}
export interface TagResourceRequest {
    
    resourceArn: string | undefined;
    
    Tags: {
        [key: string]: string;
    } | undefined;
}
export declare namespace TagResourceRequest {
    
    const filterSensitiveLog: (obj: TagResourceRequest) => any;
}
export interface TagResourceResponse {
}
export declare namespace TagResourceResponse {
    
    const filterSensitiveLog: (obj: TagResourceResponse) => any;
}
export interface UntagResourceRequest {
    
    resourceArn: string | undefined;
    
    TagKeys: string[] | undefined;
}
export declare namespace UntagResourceRequest {
    
    const filterSensitiveLog: (obj: UntagResourceRequest) => any;
}
export interface UntagResourceResponse {
}
export declare namespace UntagResourceResponse {
    
    const filterSensitiveLog: (obj: UntagResourceResponse) => any;
}
